==> kubernetes-model-core-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/NamedClusterFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface NamedClusterFluent<A extends NamedClusterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @Deprecated
  public Cluster getCluster();
  public Cluster buildCluster();
  public A withCluster(Cluster cluster);
  public Boolean hasCluster();
  public NamedClusterFluent.ClusterNested<A> withNewCluster();
  public NamedClusterFluent.ClusterNested<A> withNewClusterLike(Cluster item);
  public NamedClusterFluent.ClusterNested<A> editCluster();
  public NamedClusterFluent.ClusterNested<A> editOrNewCluster();
  public NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(Cluster item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ClusterNested<N> extends Nested<N>,ClusterFluent<NamedClusterFluent.ClusterNested<N>>{
    public N and();
    public N endCluster();
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/NamedClusterFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamedClusterFluent<A extends NamedClusterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @Deprecated
  public Cluster getCluster();
  public Cluster buildCluster();
  public A withCluster(Cluster cluster);
  public Boolean hasCluster();
  public NamedClusterFluent.ClusterNested<A> withNewCluster();
  public NamedClusterFluent.ClusterNested<A> withNewClusterLike(Cluster item);
  public NamedClusterFluent.ClusterNested<A> editCluster();
  public NamedClusterFluent.ClusterNested<A> editOrNewCluster();
  public NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(Cluster item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ClusterNested<N> extends Nested<N>,ClusterFluent<NamedClusterFluent.ClusterNested<N>>{
    public N and();
    public N endCluster();
    
  }
  
}
